@@ -426,7 +426,7 @@ is_supported_fs ()
 		return 0
 	else
 		# Then try to add support for it the gentle way using the initramfs capabilities
-		modprobe ${fstype}
+		modprobe -q -b ${fstype}
 		if grep -q ${fstype} /proc/filesystems
 		then
 			return 0
@@ -1415,7 +1415,7 @@ get_custom_mounts ()
 					union|bind)
 						;;
 					*)
-						log_warning_msg "Skipping custom mount with unkown option: ${opt}"
+						log_warning_msg "Skipping custom mount with unknown option: ${opt}"
 						continue 2
 						;;
 				esac
